@@ -11,11 +11,13 @@ import re
 from ansurr import rci_nef
 from ansurr import rigidipy
 from ansurr import compare
+from ansurr import cyrange
 
 from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
+version = "0.0.19"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -30,7 +32,7 @@ def main():
     parser.add_argument("-q", "--quiet", help="supress output to the terminal", action="store_true")
     parser.add_argument("-r", "--reref", help="re-reference shifts using PANAV before calculating RCI (requires Java)",action="store_true")
     parser.add_argument("-w", "--welldef", help="compute ANSURR scores for only well-defined residues identified by CYRANGE", action="store_true")
-    parser.add_argument("-v", "--version", action='version', version='\nANSURR | Accuracy of NMR Structures Using RCI and Rigidity v0.0.17 | citation: https://doi.org/10.1038/s41467-020-20177-1')
+    parser.add_argument("-v", "--version", action='version', version='\nANSURR | Accuracy of NMR Structures Using RCI and Rigidity v'+version+' | citation: https://doi.org/10.1038/s41467-020-20177-1')
     args = parser.parse_args()
 
     path_to_shifts = args.shifts
@@ -40,7 +42,7 @@ def main():
     pdb_file = os.path.basename(os.path.splitext(path_to_pdb)[0])
 
     now = datetime.now()
-    check_quiet_print(args.quiet,"ANSURR v0.0.17 "+now.strftime("%d/%m/%Y %H:%M:%S"))
+    check_quiet_print(args.quiet,"ANSURR v"+version+" "+now.strftime("%d/%m/%Y %H:%M:%S"))
     check_quiet_print(args.quiet," -> pdb: "+path_to_pdb)
     check_quiet_print(args.quiet," -> shifts: "+path_to_shifts)
 
@@ -64,6 +66,9 @@ def main():
         check_quiet_print(args.quiet,' -> CRITICAL ERROR failed to extract any models, exiting')
         sys.exit(1)
 
+    if args.welldef:
+        cyrange.calc_welldefined(path_to_pdb,output_dir,args.quiet)
+
     check_quiet_print(args.quiet,'computing the flexibility of each model')
     chain_output_rigidity = {}
     for pdb in sorted(pdbs,key=natsort):
